package cz.cuni.jagrlib.testing;

import cz.cuni.jagrlib.*;
import cz.cuni.jagrlib.iface.*;
import cz.cuni.jagrlib.reg.*;

/**
 * Euper operators - non-functional specimen.
 *
 * @version 0.26 $Rev: 867 $ $Date: 2009-03-16 09:03:05 +0100 (Mon, 16 Mar 2009) $ $Author: pepca $
 * @see     <a href="../../../../../cz/cuni/jagrlib/testing/EulerBrep.java">EulerBrep.java</a>
 */
public class EulerBrep extends Piece implements EulerOperators
{
  //==========================================================================
  //  Support:

  /** Accelerator. */
  protected Brep brep;

  protected final Brep getBrep ()
  {
    if ( brep == null )
      brep = (Brep)getInterface( PL_OUTPUT, IFACE+"Brep" );
    return brep;
  }

  /** Current construction context. */
  protected int context = Brep.CTX_DEFAULT;

  //==========================================================================
  //  Interface EulerOperators:

  /**
   * Set actual construction context.
   */
  public void setContext ( int ctx )
  {
    context = ctx;
  }

  /**
   * Make vertex, face, solid.
   * Creates a new (empty) shell containing a new vertex and face.
   *
   * @param  vfs Pre-allocated array to hold handles of the newly created vertex,
   *             face and solid.
   * @see    #Kvfs
   */
  public void Mvfs ( int[] vfs )
  {
  }

  /**
   * Kill vertex, face, solid.
   * Eliminates the rest of the given shell.
   *
   * @param  v Vertex handle to be deleted.
   * @param  f Face handle to be deleted.
   * @param  s Solid handle to be deleted.
   * @see    #Mvfs
   */
  public void Kvfs ( int v, int f, int s )
  {
  }

  /**
   * Make vertex, edge.
   * Add a new vetrex through a new edge | vertex split.
   *
   * @param  ve Pre-allocated array to hold handles of the newly created vertex
   *            and edge.
   * @param  v1 Handle of the 1st (already existing) vertex.
   * @param  fl Handle of the left face for the new edge.
   * @param  fr Handle of the right face for the new edge (should be the same as fl).
   * @see    #Kve
   */
  public void Mve ( int[] ve, int v1, int fl, int fr )
  {
  }

  /**
   * Kill vertex, edge.
   * Edge collapse.
   *
   * @param  v Vertex handle to be deleted.
   * @param  e Edge handle to be deleted.
   * @see    #Mve
   */
  public void Kve ( int v, int e )
  {
  }

  /**
   * Make edge, face.
   * Face split.
   *
   * @param  ef Pre-allocated array to hold handles of the newly created edge
   *            and face.
   * @param  v1 Handle of the 1st (already existing) vertex.
   * @param  v2 Handle of the 2nd (already existing) vertex.
   * @see    #Kef
   */
  public void Mef ( int[] ef, int v1, int v2 )
  {
  }

  /**
   * Kill edge, face.
   * Face join.
   *
   * @param  e Edge handle to be deleted.
   * @param  f Face handle to be deleted.
   * @see    #Mef
   */
  public void Kef ( int e, int f )
  {
  }

  /**
   * Make loop, kill edge.
   * Creates a new inner loop instead of discarded virtual edge (loop split).
   *
   * @param  e Handle of the virtual edge to be deleted.
   * @see    #KlMe
   */
  public void MlKe ( int e )
  {
  }

  /**
   * Kill loop, make edge.
   * Merges two loops (inner and outer one) using a new virtual edge.
   *
   * @param  e Pre-allocated array to hold handle of the newly created virtual edge.
   * @param  v1 Handle of the 1st (already existing) vertex.
   * @param  v2 Handle of the 2nd (already existing) vertex.
   * @param  f Face handle in which the virtual edge will be created.
   * @see    #MlKe
   */
  public void KlMe ( int[] e, int v1, int v2, int f )
  {
  }

  /**
   * Make loop, hole, kill face.
   * Punches a hole through the given (stil unconcerned) face, on the other side one existing
   * face will be deleted. Doesn't affect edges and vertices at all..
   *
   * @param  fp Handle of the face to be punched (a new loop will be created in it).
   * @param  fd Handle of the face to be deleted (its perimeter will turn into a new loop
   *            on the other side).
   * @see    #KlhMf
   */
  public void MlhKf ( int fp, int fd )
  {
  }

  /**
   * Kill loop, hole, make face.
   * Closes one existing hole using a new stopper-face.
   * Doesn't affect edges and vertices at all..
   *
   * @param  f Pre-allocated array to hold handle of the newly created stopper-face.
   * @param  fh Handle of the face containing hole (loop) to be closed.
   * @param  l Ordinal number of the loop within the face.
   * @see    #MlhKf
   */
  public void KlhMf ( int[] f, int fh, int l )
  {
  }

  //==========================================================================
  //  Interface Property:

  /**
   * Sets the given property.
   *
   * @param  key Key string.
   * @param  value The new value.
   */
  public void set ( String key, Object value )
  {
    if ( key == null || value == null ) return;

  }

  /**
   * Gets the given property.
   *
   * @param  key Key string.
   * @return The actual value or {@code null}.
   */
  public Object get ( String key )
  {
    if ( key == null ) return null;

    return null;
  }

  //==========================================================================
  //  Module registration:

  /** Object name. */
  private final static String NAME = "EulerBrep";

  /** Object template identifier. */
  protected final static String TEMPLATE_NAME = "EulerOperatorsToBrep";

  /** Object description. */
  private final static String DESCRIPTION = "Euler operators specimen (non-functional).";

  /** Object category. */
  protected final static String CATEGORY = C_3D + '.' + C_DATA + '.' + C_SCENE;

  /**
   * General-purpose registration routine.
   * Sets all plugs, strings, etc. to the given Template.
   */
  public static int setTemplate ( Template t, int ord )
  {
    if ( t != null && ord <= 0 )
    {
      t.setRegStrings( NAME, TEMPLATE_NAME, CATEGORY, DESCRIPTION );
        // Plugs:
      t.newInputPlug(  PL_INPUT,  IFACE+"EulerOperators" );
      t.newOutputPlug( PL_OUTPUT, IFACE+"Brep" );
        // Property:
    }
    return 1;
  }

  /**
   * Static registration instance for this class.
   * Automatically initialized in class-loading time.
   */
  public static final RegPiece reg;
  static
  {
    reg = new RegPiece();
    setTemplate( reg, 0 );
  }

}
